@@ -5,7 +5,10 @@ def infos(target, arg):
     target.deploy('.infos')
 
 def add(target, arg):
-    target.modules.add(arg)
+    try:
+        target.modules.add(arg)
+    except Exception as x:
+        print(x)
 
 def deploy(target, arg):
     target.deploy(arg)
@@ -20,10 +23,12 @@ def upgrade(target, arg):
     target.Package.upgrade()
 
 def installed(target, arg):
-    target.Package.installed(arg)
+    pkg = list(target.Package.installed(arg))
+    print('\n'.join(f'{n} {v}' for n, v in pkg))
 
 def available(target, arg):
-    target.Package.available(arg)
+    pkg = list(target.Package.available(arg))
+    print('\n'.join(f'{n} {v}' for n, v in pkg))
 
 def install(target, arg):
     target.Package.install(arg)
